@@ -7,7 +7,6 @@ import numpy as np
 from pydantic import validate_arguments
 from pydantic.types import NonNegativeInt, PositiveFloat, PositiveInt
 from scipy.constants import c
-
 from tidy3d.plugins.mode.solver import compute_modes as _compute_modes
 
 from ..cross_section import CrossSection
@@ -15,7 +14,7 @@ from ..mode import Mode, Modes, normalize_energy, zero_phase
 
 
 @validate_arguments
-def compute_modes(
+def compute_modes_tidy3d(
     cs: CrossSection,
     num_modes: PositiveInt = 10,
     angle_theta: float = 0.0,
@@ -67,6 +66,8 @@ def compute_modes(
                 target_neff=target_neff or cs.nx.max(),
                 sort_by=sort_by,
                 num_pml=num_pml,
+                filter_pol=None,
+                precision="double",
             ),
         )
     )
